function ai = aiupdate(aio,p,c1,c2,c3,c4,c5);
%AIUPDATE 	Update of recursive predictor coefficients ai.
% ai = aiupdate(aio,p,c1,c2,c3,c4,c5)
%
% function:	update a1 and a2 coefficient of second-order predictor
%
% input:aio  	old coefficient of second-order predictor
%		p		surrogate vector
%		c1	= 3*2^-8
%		c2	= 1-2^-8
%		c3	= 2^-7
%		c4	= 1-2^-7
%		c5	= 1-2^-4
%
% output:	ai	coefficients of second-order recursive predictor

% 1995-05-16, Martin Kummernecker
% 1995-08-30, Gernot Kubin (g.kubin@ieee.org)
% Vienna University of Technology, Vienna, Austria

sgnp = sign(p);
sgnp(2:3) = sign(sgnp(2:3) + 0.5); % modify 0's to 1's

ai(1) = c2*aio(1) + c1*sgnp(1)*sgnp(2);
if abs(aio(1)) > 0.5
   fa1 = 2*sign(aio(1));
else
   fa1 = 4*aio(1);
end;
ai(2) = c4*aio(2) + c3*(sgnp(1)*sgnp(3) - fa1*sgnp(1)*sgnp(2));
ai(2) = max(min(ai(2),0.75),-0.75);
b = c5-ai(2);
ai(1) = max(min(ai(1),b),-b);
