% script to run adpcm.m on the tfiles data base

% Gernot Kubin
% 09/07/1995

% parameters for adpcm.m
N = 40;		% bit rate in kbit/s

% Set this flag to 1 if the extendedoutput from 
% ADPCM codec is required
ExtendedOutput=1;

% filenames and headers
inputpath  = ['./in_data/']
outputpath = ['./out_data/']
filelist = [
'beep.d        '
'f4878_pcm.d   '
'm5456_pcm.d   '];

headlength = 256;		% assumes SPPACK headers

t = cputime;

% loop through all files
[m, n] = size(filelist);
for i = 1:m

	% open I/O files
	inputname  = [inputpath, deblank(filelist(i,:))]
	[infile, message] = fopen(inputname, 'r');
	if infile == -1
		error(message)
	end
	outputname = [outputpath, deblank(filelist(i,:))]
	[outfile, message] = fopen(outputname, 'w');
	if outfile == -1
		error(message)
	end

	% read input file
	x = fread(infile, 'int16');
	fclose(infile);

	% separate header
	header = x(1:headlength);
	x = x(headlength+1: length(x));
	if length(x) == 0
		error(['Input file ', inputname, ' too short!'])
	end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%     The ADPCM codec is called here 

    if ( ExtendedOutput==0 )
    	% process file with adpcm (ITU-T G.726)
    	[I, y] = adpcm( x*8191/32767, N); 
    else
        [I,y,d,dQ,scale,ai,bi] = adpcm( x*8191/32767, N);
        %I      the encoder output signal (bit stream over the channel)
        %y      decoded signal at the receiver side
        %d	    prediction difference signal
        %dQ	    quatized prediction difference signal
        %scale	scale factor for adaptive quantizer 
        %ai	    recursive predictor coefficients (2-column matrix)
        %bi	    non-recursive predictor coefficients (6-column matrix)
        
        fprintf(1,'\n Analyzing %s \n',inputname);
    end

    y = y*32767/8191;		% scale back to 16 bit
    
    % extended output
    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
	% check for overflows (w.r.t. 'int16' format) in synthetic output
	overflow = sum(abs(y) > 32767);
	if overflow > 0
		scale = 32767/max(abs(y));
		disp(['WARNING: ', num2str(overflow), ' overflows;  file ',...
	   	outputname, ' scaled down by ', num2str(scale)])
		y = y*scale;
	end

	% write output file
	y = [header; y];
	count = fwrite(outfile, y, 'int16');
	if count ~= length(y)
		error(['WARNING: error when writing ', outputname])
	end
	fclose(outfile);
    
    fprintf(1,'Type ">> dbcont"  to go to the next sound file\n');
    keyboard
end

disp(['Elapsed CPU time = ', num2str(cputime-t), ' seconds'])

	




