function y = mnru(x, Q)
%MNRU	Modulated noise reference unit.
%	MNRU(X, Q) generates an output signal by adding a synthetic white
%	Gaussian noise signal to the input signal X. The variance of 
%	the noise is controlled in a time-varying way such that it 
%	equals the local variance of the input signal X divided by the 
%	factor 10^(Q/10), i.e., Q is the equivalent signal-to-noise 
%	ratio. 
%
%	MNRU(X, Q) works for both vectors and matrices X.
%
%	This procedure is standardized by the ITU-T (former CCITT) as the
%	`modulated noise reference unit' to be used in speech transmission
%	quality assessments.

%	Gernot Kubin
%	07-27-95

% argument check
if nargin ~= 2 
	disp('Wrong number of input arguments!')
	help mnru, return
end

% generate synthetic noise N(0,1) with correct overall damping Q
n = 10^(-Q/20)*randn(size(x));

% modulate noise
%
% Here, the ITU-T standard possibly uses a different procedure (such as
% a windowed estimate of the local input variance), needs to be
% checked, but this is expected to be a negligible difference
y = x .* (1 + n);

