function [s, g] = segsnr(x, y, L, emin)
%SEGSNR	Segmental Signal-to-Noise Ratio.
%	SEGSNR(X, Y, L) is the segmental signal-to-noise ratio evaluated
%	every L samples and averaged over the whole signal duration. 
%
%			mean(10*log10(sum(X .^2)/sum((Y-X) .^2))).
%
%	SEGSNR(X, Y) uses a default segment length L = 160.
%	SEGSNR(X, Y, L, EMIN) discards all segments with energy less than
%	EMIN*L*mean(X .^2).
%	[S, G] = SEGSNR(X, Y) returns both the average segmental SNR in S 
%	and the sequence of SNRs for each segment. 
%   The evaluation is always over the duration of the shorter signal
%	only.

%	Gernot Kubin
%	07-26-1995

if (nargin < 2) | (nargin>4)
	error('SEGSNR: 2, 3, or 4 input arguments required!')
end
if exist('L') ~= 1
	L = 160;
end
if exist('emin') ~= 1
	emin = 0.0;
end
totalframes = fix(min(length(x), length(y))/L); 
duration = totalframes *L;
x = x(1:duration);
y = y(1:duration);
g = NaN*zeros(1, totalframes);

xmatrix = reshape(x(:), L, totalframes);
ematrix = reshape (y(:)-x(:), L, totalframes);
xenergy = sum(xmatrix .^2);
eenergy = sum(ematrix .^2);
valid = xenergy > emin*mean(xenergy);
g(valid) = 10*log10(xenergy(valid) ./ eenergy(valid));
s = mean(g(valid));


